@@ -23,20 +23,14 @@
 #include <TelepathyQt/Account>
 #include <TelepathyQt/AccountManager>
 #include <TelepathyLoggerQt4/Entity>
-#include <TelepathyLoggerQt4/LogWalker>
 #include <TelepathyLoggerQt4/PendingDates>
 #include <TelepathyLoggerQt4/PendingEntities>
 #include <TelepathyLoggerQt4/PendingEvents>
 #include <TelepathyLoggerQt4/PendingSearch>
-#include <TelepathyLoggerQt4/pending-clear.h>
 #include <TelepathyLoggerQt4/utils.h>
-
 #include <telepathy-logger/log-manager.h>
 #include <telepathy-glib/account.h>
 
-#include <_gen/cli-logger-body.hpp>
-#include <_gen/cli-logger.moc.hpp>
-
 using namespace Tpl;
 
 LogManagerPtr LogManager::instance()
@@ -91,53 +85,3 @@ PendingSearch *LogManager::search(const QString &text, EventTypeMask typeMask)
 {
     return new PendingSearch(LogManagerPtr(this), text, typeMask);
 }
-
-PendingOperation *LogManager::clearHistory()
-{
-    PendingClear *operation = new PendingClear();
-
-    operation->clearLog();
-
-    return operation;
-}
-
-PendingOperation *LogManager::clearAccountHistory(const Tp::AccountPtr &account)
-{
-    PendingClear *operation = new PendingClear();
-
-    operation->clearAccount(account);
-
-    return operation;
-}
-
-PendingOperation *LogManager::clearEntityHistory(const Tp::AccountPtr &account, const EntityPtr &entity)
-{
-    PendingClear *operation = new PendingClear();
-
-    if (entity->entityType() == EntityTypeContact) {
-        operation->clearContact(account, entity->identifier());
-    } else if (entity->entityType() == EntityTypeRoom) {
-        operation->clearRoom(account, entity->identifier());
-    } else {
-        return 0;
-    }
-
-    return operation;
-}
-
-LogWalkerPtr LogManager::queryWalkFilteredEvents(const Tp::AccountPtr& account,
-        const EntityPtr& entity, EventTypeMask typeMask, LogEventFilter filterFunction,
-        void* filterFunctionUserData)
-{
-    TpAccount *tpAccount = Utils::instance()->tpAccount(account);
-    if (!tpAccount) {
-        qWarning() << "Invalid account";
-        return LogWalkerPtr();
-    }
-
-    TplLogWalker *tpWalker = tpl_log_manager_walk_filtered_events(
-                                LogManagerPtr(this), tpAccount, entity,
-                                (gint) typeMask, (TplLogEventFilter) filterFunction,
-                                filterFunctionUserData);
-    return LogWalkerPtr::wrap(tpWalker, false);
-}
