@@ -42,32 +42,3 @@ QString TextEvent::messageToken() const
     QString str = QString::fromUtf8(s);
     return str;
 }
-
-QDateTime TextEvent::editTimestamp() const
-{
-    // FIXME See http://bugs.freedesktop.org/show_bug.cgi?id=21690
-    uint seconds = (uint) tpl_text_event_get_edit_timestamp(object<TplTextEvent>());
-    QDateTime dateTime;
-    dateTime.setTime_t(seconds);
-    return dateTime;
-}
-
-QString TextEvent::supersedesToken() const
-{
-    const gchar *s = tpl_text_event_get_supersedes_token(object<TplTextEvent>());
-    QString str = QString::fromUtf8(s);
-    return str;
-}
-
-
-QList< TextEventPtr > TextEvent::supersedes() const
-{
-    GList *tplEvents = tpl_text_event_get_supersedes(object<TplTextEvent>());
-    GList *iter;
-    QList<TextEventPtr> events;
-    for (iter = tplEvents; iter; iter = g_list_next(iter)) {
-        events << TextEventPtr::wrap((TplTextEvent*) iter->data, true);
-    }
-
-    return events;
-}
