@@ -34,37 +34,28 @@ namespace Tpl
 enum EntityType
 {
     //codegen: EntityTypeUnknown=ENTITY_UNKNOWN,EntityTypeContact=ENTITY_CONTACT,EntityTypeRoom=ENTITY_ROOM,EntityTypeSelf=ENTITY_SELF
-    EntityTypeUnknown, /**< the current contact's type is unknown **/
-    EntityTypeContact, /**< the the contact's type represents a user (buddy), but not
-                         the account's owner for which EntityTypeSelf is used **/
-    EntityTypeRoom,    /**< a named room **/
-    EntityTypeSelf     /**< the contact's type represents the owner of the account
-                         whose channel has been logged, as opposed to 
-                         EntityTypeContact which represents any other user */
+    EntityTypeUnknown,
+    EntityTypeContact,
+    EntityTypeRoom,
+    EntityTypeSelf
 };
 
 enum LogManagerError
 {
-    LogManagerErrorAddEvent /**  Error returned when adding logs fails **/
+    LogManagerErrorAddEvent
 };
 
-/**
- * \brief Mask used to filter type of Tpl::Event returned.
- */
 enum EventTypeMask
 {
-    //codegen: EventTypeMaskText=EVENT_MASK_TEXT,EventTypeMaskCall=EVENT_MASK_CALL,EventTypeMaskAny=EVENT_MASK_ANY
-    EventTypeMaskText = 1 << 0, /**< Mask to Tpl::TextEvent **/
-    EventTypeMaskCall = 1 << 1, /**< Mask to Tpl::CallEvent **/
-    EventTypeMaskAny = 0xffff   /**< Special value to select all type of Tpl::Event **/
+    //codegen: EventTypeMaskText=EVENT_MASK_TEXT,EventTypeMaskAny=EVENT_MASK_ANY
+    EventTypeMaskText = 1 << 0,
+    EventTypeMaskAny = 0xffff
 };
 
 class Logger;
-class LogWalker;
 class PendingDates;
 class PendingEvents;
 class PendingEntities;
-class PendingOperation;
 class PendingSearch;
 struct SearchHit;
 
